@@ -1,4 +1,4 @@
-.densParzenWindow.xy <- function(x, y, hx, hy)
+.densParzenWindow.xy <- function(x, y, hx, hy, npts)
 {
   output <- .C("RdensParzenWindowXY",
     n = as.integer(length(x)),
@@ -14,11 +14,21 @@
     stop("in densParzenWindow.xy!", call. = FALSE); return(NA)
   }
 
-  i <- order(output$z)
+  i <- !duplicated(data.frame(output$x, output$y))
 
-  output$x <- output$x[i]
+  output$x <- output$x[i] 
   output$y <- output$y[i]
-  output$z <- output$z[i]
+  output$z <- output$z[i]  
+  
+  n <- length(output$z)
+  
+  if (n > npts) {
+    i <- sample.int(n, npts, replace = FALSE, prob = NULL)  
+  
+    output$x <- output$x[i]
+    output$y <- output$y[i]
+    output$z <- output$z[i]
+  }
 
   rm(list = ls()[!(ls() %in% c("output"))])
 
